==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/security.php <==
<?php
/**
 * UTF8
 * stanislav.elbl, 08.09.2015
 */

namespace RonPortal;


use Ron\DB\Database;
use Ron\StringUtils;
use Ron\TextManager;

class PasswordPolicy
{
    var $length;
    var $uroven;  // uroven 0=bez omezeni, 1=velka a mala pismena, 2=1+cisla, 3=2+specialni znaky
    var $platnost;

    function __construct() {
        $this ->length = 0;
        $this ->uroven = 0;
        $this ->platnost = 0;
    }
}


class Security
{
    /**
     * @param Database $database
     * @return PasswordPolicy
     * @throws \Exception
     */
    public static function getPasswordPolicy($database)
    {
        $cursor = $database ->getSqlResult("SELECT ApplicationID, Val FROM SYS_VAR WHERE Name = 'PP' ORDER BY ApplicationID", null, 'Chyba pri zjistovani politiky hesel!');
        $row = $cursor ->fetch();
        $cursor ->close();

        $result = new PasswordPolicy();

        if ($row) {
            $poma = explode(';', $row[1]);

            $result ->length = (int)$poma[0];
            $result ->uroven = (int)$poma[1];
            $result ->platnost = (int)$poma[2];
        }

        return $result;
    }


    /**
     * @param string $newPassword
     * @param PasswordPolicy $policy
     * @return bool
     * @throws \Exception
     */
    public static function checkPasswordPolicy($newPassword, $policy)
    {
        if (strlen($newPassword) < (int)$policy->length) {
            throw new \Exception(sprintf(TextManager::_('Minimalni_delka_hesla'), $policy->length));
        }

        // kontrola urovne hesla - spocita pismena, cisla atd.
        $velke = false;
        $male = false;
        $cislo = false;
        $znak = false;
        for ($i = 0; $i < strlen($newPassword); $i++) {
            if ($newPassword[$i] >= 'a' && $newPassword[$i] <= 'z') $male = true;
            else if ($newPassword[$i] >= 'A' && $newPassword[$i] <= 'Z') $velke = true;
            else if ($newPassword[$i] >= '0' && $newPassword[$i] <= '9') $cislo = true;
            else $znak = true;
        }

        // kontrola urovne hesla - overi spocitane znaky podle nastaveni
        $error = false;
        if ((int)$policy->uroven > 0 && !$velke) $error = true;
        if ((int)$policy->uroven > 0 && !$male) $error = true;
        if ((int)$policy->uroven > 1 && !$cislo) $error = true;
        if ((int)$policy->uroven > 2 && !$znak) $error = true;

        if ($error) {
            // zobrazi chybovou hlasku
            $pomstr = '';
            if ($policy->uroven > 0) $pomstr = TextManager::_('Heslo_male_pismeno') . ', ' . TextManager::_('Heslo_velke_pismeno');
            if ($policy->uroven > 1) $pomstr .= ', ' . TextManager::_('Heslo_cislice');
            if ($policy->uroven > 2) $pomstr .= ', ' . TextManager::_('Heslo_jiny_znak');

            throw new \Exception(sprintf(TextManager::_('Heslo_musi_obsahovat'), $pomstr));
        }

        return true;
    }


    /**
     * @param Database $database
     * @return string
     */
    public static function getPasswordType($database)
    {
        $cursor = $database ->select("SELECT Val FROM SYS_VAR WHERE Name = 'PasswordType'");

        $row = $cursor ->fetch();

        if ($row) return $row[0];

        return 'RON';
    }


    /**
     * @param string $passwordType
     * @param string $password
     * @return string
     */
    public static function encodePassword($passwordType, $password)
    {
        switch ($passwordType) {
            case 'SHA1' :
                return sha1($password);

            case 'MD5' :
                return md5($password);

            default :   // Kodovani RON
                return StringUtils::strToHexa(strtoupper($password));
        }
    }


    /**
     * Nacte z databaze zakodovane heslo uzivatele
     * @param Database $database
     * @param string $RC
     * @return string mixed
     * @throws \Exception
     * @throws \Ron\DB\DBException
     */
    public static function loadUserPassword($database, $RC)
    {
        $params = $database ->createParameters();
        $sql =
            'SELECT IntrawebPassword  FROM Osoba ' .
            ' WHERE RC = ' . $params->addParameter($RC);

        $cursor = $database ->getSqlResult($sql, $params);
        $row = $cursor ->fetch();
        $cursor ->close();

        if (!$row) throw new \Exception('Uzivatel nenalezen!');

        return $row[0];
    }


    /**
     * Zkontroluje shodu zadaneho hesla a hesla z database.
     * @param string $passwordType  Zpusob kodovani hesla
     * @param string $inputPassword   Heslo zadane uzivatelem
     * @param string $dbPassword    Heslo z databaze
     * @return bool
     */
    public static function checkPassword($passwordType, $inputPassword, $dbPassword)
    {
        // TODO: implementovat volbu password_hash - asi ne, neslo by zmenit v aplikaci

        switch ($passwordType) {
            case 'SHA1' :
                if (strtoupper(sha1($inputPassword)) != strtoupper($dbPassword)) return false;
                break;

            case 'MD5' :
                if (strtoupper(md5($inputPassword)) != strtoupper($dbPassword)) return false;
                break;

            default :   // Kodovani RON
                /*
                // Starsi verze PHP vraci z databaze misto prazdneho retezce mezeru!
                // Pokud uzivatel zadal prazdne heslo a v databazi je mezera, tak
                // uz zadane heslo nekontroluje, jinak ho porovna s heslem v databazi
                if (($dbPassword != ' ')  ||  $inputPasswd) {
                    // Kvuli kodovani cestiny je ted noveji heslo zakodovano do hexadecimalni
                    // reprezentace. Tady zkontroluje jestli heslo odpovida podle puvodniho
                    // kodovani nebo v te hexa reprezentaci - povoli oboji.
                    // Pokud heslo neodpovida, tak nacteny radek z databaze zrusi (unset $row)
                    if (strcasecmp(strToHexa(strtoupper($inputPasswd)), $dbPassword)) {
                        $inputPasswd = strEncrypt($inputPasswd);
                        if ($dbPassword != $inputPasswd) return false;
                    }
                }
                */

                if (strcasecmp(StringUtils::strToHexa(strtoupper($inputPassword)), $dbPassword)) return false;

                break;
        }

        return true;
    }


    /**
     * Zkontroluje heslo uzivatele.
     * @param Database $database
     * @param string $RC
     * @param string $inputPassword
     * @return bool
     * @throws \Ron\DB\DBException
     */
    public static function checkUserPassword($database, $RC, $inputPassword)
    {
        $dbPassword = self::loadUserPassword($database, $RC);
        $passwordType = self::getPasswordType($database);
        return self::checkPassword($passwordType, $inputPassword, $dbPassword);
    }


    public static function ldapConnect()
    {
        global $ldap_server;
        global $ldap_port;
        global $ldap_options;
        global $ldap_tls;

        $ds = isset($ldap_port) ? ldap_connect($ldap_server, $ldap_port) : ldap_connect($ldap_server);

        if (!$ds) {
            throw new \Exception('Nelze se pripojit k LDAP serveru (funkce ldap_connect)!');
        }

        if (isset($ldap_options)) {
            foreach ($ldap_options as $option => $value) {
                ldap_set_option($ds, $option, $value);
            }
        }

        if (isset($ldap_tls)  &&  $ldap_tls) {
            if (!ldap_start_tls($ds)) {
                throw new \Exception('Nelze se pripojit k LDAP serveru pomoci TLS!');
            }
        }

        return $ds;
    }

    /**
     * Vraci DN (distinguishedname) pro uzivatele se zadanym loginem (samaccountname)
     * @param string $loginName
     * @return string
     * @throws \Exception
     */
    public static function getLdapDN($loginName)
    {
        global $ldap_user;
        global $ldap_password;
        global $ldap_search_dn;
        global $ldap_search_filter;

        $ds = self::ldapConnect();

        if (ldap_bind($ds, $ldap_user, $ldap_password)) {
            $filter = $ldap_search_filter
                ? str_replace('{$loginname}', $loginName, $ldap_search_filter)
                : '(sAMAccountName=' . $loginName . ')';
            $sr = ldap_search($ds, $ldap_search_dn, $filter);
            if (!$sr) {
                ldap_get_option($ds, LDAP_OPT_ERROR_STRING, $extended_error);
                throw new \Exception('Chyba pri vyhledavani uzivatele - volani ldap_search nevratilo vysledek. Zkontrolujte konfiguraci pripojeni k ldap serveru! Chyba: ' . $extended_error );
            }

            $entry = ldap_get_entries($ds, $sr);
            if (!$entry) {
                ldap_get_option($ds, LDAP_OPT_ERROR_STRING, $extended_error);
                throw new \Exception('Chyba pri vyhledavani uzivatele - volani ldap_get_entries nevratilo vysledek. Zkontrolujte konfiguraci pripojeni k ldap serveru! Chyba: ' . $extended_error );
            }

            if (!$entry['count']) return false; // uzivatel nenalezen - spatne jmeno
            if (!$entry[0]['dn']) {
                throw new \Exception('Chyba pri vyhledavani uzivatele - zaznam vraceny funkci ldap_search neobsahuje dn!');
            }

            ldap_unbind($ds);

            return $entry[0]['dn'];
        } else {
            throw new \Exception('Nelze se pripojit k ldap serveru nastavenym servisnim uctem!');
            }
    }


    /**
     * @param string $loginName
     * @param string $loginPassword
     * @return bool|null    V pripade, ze ucet vubec neexistuje (lze zjistit, jen kdyz je nastaven $ldap_user) vraci null
     *                      Jinak vraci true v pripade uspesneho overeni hesla a false v pripade neuspesneho
     * @throws \Exception
     */
    public static function checkLDAPLogin($loginName, $loginPassword)
    {
        global $ldap_nameprefix;
        global $ldap_namesuffix;
        global $ldap_user;

        if (!$loginPassword) {
            throw new \Exception(TextManager::_('Heslo_nesmi_byt_prazdne'));
        }

        if ($ldap_user) {
            // je zadan servisni ucet - prihlasi se servisnim uctem a zjisti DN uzivatele
            $dn = self::getLdapDN($loginName);
            if (!$dn) {
                return null;
            }
        } else {
            $dn = null;
        }

        $ds = self::ldapConnect();

        if ($dn) {
            $result = ldap_bind($ds, $dn, $loginPassword);
        } else {
            $result = ldap_bind($ds, $ldap_nameprefix . $loginName . $ldap_namesuffix, $loginPassword);
        }

        ldap_unbind($ds);
        return !!$result;
    }

}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/security.php <==
<?php
/**
 * stanislav.elbl, 08.09.2015
 */

namespace RonPortal;


use Ron\DB\Database;
use Ron\GuiUtils;
use Ron\StringUtils;
use Ron\TextManager;

class PasswordPolicy
{
    var $length;
    var $uroven;  // uroven 0=bez omezeni, 1=velka a mala pismena, 2=1+cisla, 3=2+specialni znaky
    var $platnost;

    function __construct() {
        $this ->length = 0;
        $this ->uroven = 0;
        $this ->platnost = 0;
    }
}


class Security
{
    /**
     * @param Database $database
     * @return PasswordPolicy
     * @throws \Exception
     */
    public static function getPasswordPolicy($database)
    {
        $cursor = $database ->getSqlResult(
            "SELECT ApplicationID, Val FROM SYS_VAR WHERE Name = 'PP' ORDER BY ApplicationID", null,
            'Chyba pri zjistovani politiky hesel!');
        $row = $cursor ->fetch();
        $cursor ->close();

        $result = new PasswordPolicy();

        if ($row) {
            $poma = explode(';', $row[1]);

            $result ->length = (int)$poma[0];
            $result ->uroven = (int)$poma[1];
            $result ->platnost = (int)$poma[2];
        }

        return $result;
    }


    /**
     * @param string $newPassword
     * @param PasswordPolicy $policy
     * @return bool
     * @throws \Exception
     */
    public static function checkPasswordPolicy($newPassword, $policy)
    {
        if (strlen($newPassword) < (int)$policy->length) {
            throw new \Exception(sprintf(TextManager::_('Minimalni_delka_hesla'), $policy->length));
        }

        // kontrola urovne hesla - spocita pismena, cisla atd.
        $velke = false;
        $male = false;
        $cislo = false;
        $znak = false;
        for ($i = 0; $i < strlen($newPassword); $i++) {
            if ($newPassword[$i] >= 'a' && $newPassword[$i] <= 'z') {
                $male = true;
            } else if ($newPassword[$i] >= 'A' && $newPassword[$i] <= 'Z') {
                $velke = true;
            } else if ($newPassword[$i] >= '0' && $newPassword[$i] <= '9') {
                $cislo = true;
            } else {
                $znak = true;
            }
        }

        // kontrola urovne hesla - overi spocitane znaky podle nastaveni
        $error = false;
        if ((int)$policy->uroven > 0 && !$velke) {
            $error = true;
        }
        if ((int)$policy->uroven > 0 && !$male) {
            $error = true;
        }
        if ((int)$policy->uroven > 1 && !$cislo) {
            $error = true;
        }
        if ((int)$policy->uroven > 2 && !$znak) {
            $error = true;
        }

        if ($error) {
            // zobrazi chybovou hlasku
            $pomstr = '';
            if ($policy->uroven > 0) {
                $pomstr = TextManager::_('Heslo_male_pismeno') . ', ' . TextManager::_('Heslo_velke_pismeno');
            }
            if ($policy->uroven > 1) {
                $pomstr .= ', ' . TextManager::_('Heslo_cislice');
            }
            if ($policy->uroven > 2) {
                $pomstr .= ', ' . TextManager::_('Heslo_jiny_znak');
            }

            throw new \Exception(sprintf(TextManager::_('Heslo_musi_obsahovat'), $pomstr));
        }

        return true;
    }


    /**
     * @param Database $database
     * @return string
     */
    public static function getPasswordType($database)
    {
        $cursor = $database ->select(
            "SELECT Val FROM SYS_VAR WHERE Name = 'PasswordType'");

        $row = $cursor ->fetch();

        if ($row) {
            return $row[0];
        }

        return 'SHA1';
    }


    /**
     * @param string $passwordType
     * @param string $password
     * @return string
     */
    public static function encodePassword($passwordType, $password)
    {
        switch ($passwordType) {
            case 'RON' :
                return StringUtils::strToHexa(strtoupper($password));

            case 'MD5' :
                return md5($password);

            default :
                return sha1($password);
        }
    }


    /**
     * Nacte z databaze zakodovane heslo uzivatele
     * @param Database $database
     * @param string $RC
     * @return string mixed
     * @throws \Exception
     * @throws \Ron\DB\DBException
     */
    public static function loadUserPassword($database, $RC)
    {
        $params = $database ->createParameters();
        $sql =
            'SELECT IntrawebPassword  FROM Osoba ' .
            ' WHERE RC = ' . $params->addParameter($RC);

        $cursor = $database ->getSqlResult($sql, $params);
        $row = $cursor ->fetch();
        $cursor ->close();

        if (!$row) {
            throw new \Exception('Uzivatel nenalezen!');
        }

        return $row[0];
    }


    /**
     * Zkontroluje shodu zadaneho hesla a hesla z database.
     * @param string $passwordType  Zpusob kodovani hesla
     * @param string $inputPassword   Heslo zadane uzivatelem
     * @param string $dbPassword    Heslo z databaze
     * @return bool
     */
    public static function checkPassword($passwordType, $inputPassword, $dbPassword)
    {
        // TODO: implementovat volbu password_hash - asi ne, neslo by zmenit v aplikaci

        switch ($passwordType) {
            case 'SHA1' :
                if (strtoupper(sha1($inputPassword)) != strtoupper($dbPassword)) {
                    return false;
                }
                break;

            case 'MD5' :
                if (strtoupper(md5($inputPassword)) != strtoupper($dbPassword)) {
                    return false;
                }
                break;

            default :   // Kodovani RON
                /*
                // Starsi verze PHP vraci z databaze misto prazdneho retezce mezeru!
                // Pokud uzivatel zadal prazdne heslo a v databazi je mezera, tak
                // uz zadane heslo nekontroluje, jinak ho porovna s heslem v databazi
                if (($dbPassword != ' ')  ||  $inputPasswd) {
                    // Kvuli kodovani cestiny je ted noveji heslo zakodovano do hexadecimalni
                    // reprezentace. Tady zkontroluje jestli heslo odpovida podle puvodniho
                    // kodovani nebo v te hexa reprezentaci - povoli oboji.
                    // Pokud heslo neodpovida, tak nacteny radek z databaze zrusi (unset $row)
                    if (strcasecmp(strToHexa(strtoupper($inputPasswd)), $dbPassword)) {
                        $inputPasswd = strEncrypt($inputPasswd);
                        if ($dbPassword != $inputPasswd) return false;
                    }
                }
                */

                if (strcasecmp(StringUtils::strToHexa(strtoupper($inputPassword)), $dbPassword)) {
                    return false;
                }

                break;
        }

        return true;
    }


    /**
     * Zkontroluje heslo uzivatele.
     * @param Database $database
     * @param string $RC
     * @param string $inputPassword
     * @return bool
     * @throws \Ron\DB\DBException
     */
    public static function checkUserPassword($database, $RC, $inputPassword)
    {
        $dbPassword = self::loadUserPassword($database, $RC);
        $passwordType = self::getPasswordType($database);
        return self::checkPassword($passwordType, $inputPassword, $dbPassword);
    }


    public static function ldapConnect()
    {
        global $ldap_server;
        global $ldap_port;
        global $ldap_options;
        global $ldap_tls;

        $ds = isset($ldap_port)
            ? ldap_connect($ldap_server, $ldap_port)
            : ldap_connect($ldap_server);

        if (!$ds) {
            throw new \Exception('Nelze se pripojit k LDAP serveru (funkce ldap_connect)!');
        }

        if (isset($ldap_options)) {
            foreach ($ldap_options as $option => $value) {
                ldap_set_option($ds, $option, $value);
            }
        }

        if (isset($ldap_tls)  &&  $ldap_tls) {
            if (!ldap_start_tls($ds)) {
                throw new \Exception('Nelze se pripojit k LDAP serveru pomoci TLS!');
            }
        }

        return $ds;
    }

    /**
     * Vraci DN (distinguishedname) pro uzivatele se zadanym loginem (samaccountname)
     * @param string $loginName
     * @return string
     * @throws \Exception
     */
    public static function getLdapDN($loginName)
    {
        global $ldap_user;
        global $ldap_password;
        global $ldap_search_dn;
        global $ldap_search_filter;

        $ds = self::ldapConnect();

        if (ldap_bind($ds, $ldap_user, StringUtils::toUTF8($ldap_password))) {
            $filter = $ldap_search_filter
                ? str_replace('{$loginname}', $loginName, $ldap_search_filter)
                : '(sAMAccountName=' . $loginName . ')';
            $sr = ldap_search($ds, $ldap_search_dn, $filter);
            if (!$sr) {
                ldap_get_option($ds, LDAP_OPT_ERROR_STRING, $extended_error);
                throw new \Exception('Chyba pri vyhledavani uzivatele - volani ldap_search nevratilo vysledek. Zkontrolujte konfiguraci pripojeni k ldap serveru! Chyba: ' . $extended_error );
            }

            $entry = ldap_get_entries($ds, $sr);
            if (!$entry) {
                ldap_get_option($ds, LDAP_OPT_ERROR_STRING, $extended_error);
                throw new \Exception('Chyba pri vyhledavani uzivatele - volani ldap_get_entries nevratilo vysledek. Zkontrolujte konfiguraci pripojeni k ldap serveru! Chyba: ' . $extended_error );
            }

            if (!$entry['count']) {
                // uzivatel nenalezen - spatne jmeno
                return false;
            }

            if (!$entry[0]['dn']) {
                throw new \Exception('Chyba pri vyhledavani uzivatele - zaznam vraceny funkci ldap_search neobsahuje dn!');
            }

            ldap_unbind($ds);

            return $entry[0]['dn'];
        } else {
            throw new \Exception('Nelze se pripojit k ldap serveru nastavenym servisnim uctem!');
        }
    }


    /**
     * @param string $loginName
     * @param string $loginPassword
     * @return bool|null    V pripade, ze ucet vubec neexistuje (lze zjistit, jen kdyz je nastaven $ldap_user) vraci null
     *                      Jinak vraci true v pripade uspesneho overeni hesla a false v pripade neuspesneho
     * @throws \Exception
     */
    public static function checkLDAPLogin($loginName, $loginPassword)
    {
        global $ldap_nameprefix;
        global $ldap_namesuffix;
        global $ldap_user;

        if (!$loginPassword) {
            throw new \Exception(TextManager::_('Heslo_nesmi_byt_prazdne'));
        }

        if ($ldap_user) {
            // je zadan servisni ucet - prihlasi se servisnim uctem a zjisti DN uzivatele
            $dn = self::getLdapDN($loginName);
            if (!$dn) {
                return null;
            }
        } else {
            $dn = null;
        }

        $ds = self::ldapConnect();
        // TODO: osetrit hesla s diakritikou: mozna pomuze toto:
        // ldap_bind($ldap, htmlspecialchars_decode($config['ldap_user']), htmlspecialchars_decode($config['ldap_password']))
        // viz  https://forums.cacti.net/viewtopic.php?t=52430
        if ($dn) {
            $result = ldap_bind($ds, $dn, StringUtils::toUTF8($loginPassword));
        } else {
            $result = ldap_bind($ds, StringUtils::toUTF8($ldap_nameprefix . $loginName . $ldap_namesuffix), StringUtils::toUTF8($loginPassword));
        }

        ldap_unbind($ds);
        return !!$result;
    }

    const CSRF_RANDOM_LEN = 8;


    private static function getCsrfToken()
    {
        // pri prihlaseni vygeneruje nahodny csrf token platny po celou session
        if (!isset($_SESSION['csrf_token'])  ||  !$_SESSION['csrf_token']) {
            $_SESSION['csrf_token'] = bin2hex(random_bytes(16));
        }

        return $_SESSION['csrf_token'];
    }

    /**
     * Vygeneruje CSRF klic pro zadany request. Tento klic pak lze pouzit pro kontrolu metodou validateCSRFKey
     * @return string
     */
    public static function getCsrfKey()
    {
        global $csrf;
        if (!$csrf) {
            return '';
        }
//        global $CSRF_key;
//        if (!$CSRF_key) {
//            return '';
//        }

        $randomStr = bin2hex(random_bytes(self::CSRF_RANDOM_LEN));
        return $randomStr . hash_hmac('sha1', $randomStr, self::getCsrfToken());
        //return sha1($requestString. $CSRF_key . $_SESSION['csrf_token']);
    }


    /**
     * Vygeneruje CSRF klic pro zadany request (viz metoda csrfKeyForRequest) a vraci url parametr s timto klicem
     * @param string $keyParameterName
     * @return string
     */
    public static function csrfUrlParameter($keyParameterName = 'csrfkey')
    {
        $key = self::getCsrfKey();
        if ($key) {
            return '&' . $keyParameterName . '=' . $key;
        }

        return '';
    }


    public static function csrfHiddenInput($htmlParams = [])
    {
        $key = self::getCsrfKey();
        if ($key) {
            return "<input " . GuiUtils::getAttributesHtml(array_merge(
                ['type' => 'hidden', 'name' => 'csrfkey'],
                $htmlParams
            )) . " value='$key'/>";
        }

        return '';
    }

    public static function validateCSRFKey($key)
    {
        if (hash_hmac('sha1', substr($key, 0, 2*self::CSRF_RANDOM_LEN), self::getCsrfToken()) != substr($key, 2*self::CSRF_RANDOM_LEN)) {
            throw new \Exception(TextManager::_('Overovaci_klic_jiz_neni_platny'));
        }
    }

    /**
     * Overi platnost CSRF klice z GET pozadavku pro zadany requestString
     * @param string $keyParameterName
     * @throws \Exception
     */
    public static function validateCSRFGetParam($keyParameterName = 'csrfkey')
    {
        global $csrf;
        if ($csrf) {
            self::validateCSRFKey(isset($_GET[$keyParameterName]) ? $_GET[$keyParameterName] : '');
//            if (!isset($_GET[$keyParameterName])  ||  $_GET[$keyParameterName] !== self::csrfKeyForRequest($requestString)) {
//                throw new \Exception(TextManager::_('Overovaci_klic_jiz_neni_platny'));
//            }
        }
    }


    /**
     * Overi platnost CSRF klice z POST pozadavku pro zadany requestString
     * @param string $keyParameterName
     * @throws \Exception
     */
    public static function validateCSRFPostParam($keyParameterName = 'csrfkey')
    {
        global $csrf;
        if ($csrf) {
            self::validateCSRFKey(isset($_POST[$keyParameterName]) ? $_POST[$keyParameterName] : '');
        }
    }
}
